@webUI
Feature: Logging

  Background:
    Given the owncloud log backend has been set to "owncloud"
    And the owncloud log has been cleared
    And these users have been created with skeleton files:
      | username |
      | Alice    |
    And the administrator has logged in using the webUI
    And the user has browsed to the File Firewall settings page
    And the user has created an empty firewall rule group named "limiter"

  Scenario: logging of not blocked file access when logging is set to "All Requests"
    When the user places a rule with the filter "Request Type", the operator "is not" and the value "WebDAV" in the group named "limiter"
    And the user saves the firewall rules
    And the user sets the firewall logging level to "All Requests"
    And the owncloud log level is set to "info"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the last lines of the log file should contain log-entries with these attributes:
      | user  | app      | method | message                  |
      | Alice | firewall | GET    | Firewall allowed request |
    When the owncloud log level is set to "warning"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |

  Scenario: logging of blocked file access when logging is set to "All Requests"
    When the user places a rule with the filter "Request Type", the operator "is" and the value "WebDAV" in the group named "limiter"
    And the user saves the firewall rules
    And the owncloud log level is set to "warning"
    And the user sets the firewall logging level to "All Requests"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the last lines of the log file should contain log-entries with these attributes:
      | user  | app      | method | message                                                   |
      | Alice | firewall | GET    | Firewall blocked request due to a matching rule "limiter" |
      | Alice | webdav   | GET    |                                                           |
    When the owncloud log level is set to "error"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |

  Scenario: logging of blocked file access when logging is set to "Blocked Requests Only"
    When the user places a rule with the filter "Request Type", the operator "is" and the value "WebDAV" in the group named "limiter"
    And the user saves the firewall rules
    And the owncloud log level is set to "warning"
    And the user sets the firewall logging level to "Blocked Requests Only"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the last lines of the log file should contain log-entries with these attributes:
      | user  | app      | method | message                                                   |
      | Alice | firewall | GET    | Firewall blocked request due to a matching rule "limiter" |
      | Alice | webdav   | GET    |                                                           |
    When the owncloud log level is set to "error"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |

  Scenario: do not log not blocked file access when logging is set to "Blocked Requests Only"
    When the user places a rule with the filter "Request Type", the operator "is not" and the value "WebDAV" in the group named "limiter"
    And the user saves the firewall rules
    And the owncloud log level is set to "info"
    And the user sets the firewall logging level to "Blocked Requests Only"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
    When the owncloud log level is set to "warning"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |

  Scenario: do not log anything from the firewall app when logging is set to "Off"
    When the user places a rule with the filter "Request Type", the operator "is" and the value "WebDAV" in the group named "limiter"
    And the user saves the firewall rules
    And the owncloud log level is set to "fatal"
    And the user sets the firewall logging level to "Off"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
    When the owncloud log level is set to "error"
    And the user sets the firewall logging level to "Off"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
    When the owncloud log level is set to "warning"
    And the user sets the firewall logging level to "Off"
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
    When the owncloud log level is set to "info"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
    When the owncloud log level is set to "debug"
    And the owncloud log is cleared
    And user "Alice" downloads file "lorem.txt" using the WebDAV API
    Then the log file should not contain any log-entries with these attributes:
      | app      |
      | firewall |
