<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Engine\Wrapper;

use OCA\Workflow\Engine\Wrapper\StorageWrapper;
use Test\TestCase;

class StorageWrapperTest extends TestCase {

	/** @var \OC\Files\Storage\Storage|\PHPUnit\Framework\MockObject\MockObject */
	protected $storage;

	/** @var \OCA\Workflow\Engine\Plugin|\PHPUnit\Framework\MockObject\MockObject */
	protected $plugin;

	protected function setUp(): void {
		parent::setUp();

		$this->storage = $this->getMockBuilder('OC\Files\Storage\Storage')
			->disableOriginalConstructor()
			->getMock();

		$this->plugin = $this->getMockBuilder('OCA\Workflow\Engine\Plugin')
			->disableOriginalConstructor()
			->getMock();
	}

	/**
	 * @param array $methods
	 * @return StorageWrapper|\PHPUnit\Framework\MockObject\MockObject
	 */
	protected function getInstance(array $methods = []) {
		if (empty($methods)) {
			return new StorageWrapper([
				'storage' => $this->storage,
				'mountPoint' => 'mountPoint',
				'plugin' => $this->plugin,
			]);
		} else {
			return $this->getMockBuilder('OCA\Workflow\Engine\Wrapper\StorageWrapper')
				->setConstructorArgs([
					[
						'storage' => $this->storage,
						'mountPoint' => 'mountPoint',
						'plugin' => $this->plugin,
					]
				])
				->setMethods($methods)
				->getMock();
		}
	}

	/*
	 * Storage Wrapper methods
	 * =======================================================================
	 */

	public function dataGetCache() {
		return [
			[false, true],
			[true, false],
		];
	}

	/**
	 * @dataProvider dataGetCache
	 *
	 * @param bool $isShared
	 * @param bool $expectedLocal
	 */
	public function testGetCache($isShared, $expectedLocal) {
		$wrapper = $this->getInstance();

		$this->storage->expects($this->once())
			->method('getCache')
			->with('', $wrapper)
			->willReturn($this->createMock(\OCP\Files\Cache\ICache::class));

		$this->storage->expects($this->once())
			->method('instanceOfStorage')
			->with('OC\Files\Storage\Shared')
			->willReturn($isShared);

		$cache = $wrapper->getCache('', null);
		$this->assertInstanceOf('OCA\Workflow\Engine\Wrapper\CacheWrapper', $cache);
		$this->assertSame($expectedLocal, $this->invokePrivate($cache, 'isLocalStorage'));
	}
}
