<?php
/**
 * ownCloud Workflow
 *
 * @author Viktar Dubiniuk <dubiniuk@owncloud.com>
 * @copyright 2019 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Retention;

use OCA\Workflow\Entity\Property as DbProperty;
use OCA\Workflow\Entity\PropertyMapper;
use OCA\Workflow\Retention\RetentionChecker;
use OCA\Workflow\Tests\Unit\TestCase;
use OCP\Files\Node;
use OCP\IConfig;
use OCP\ILogger;
use PHPUnit\Framework\MockObject\MockObject;

class RetentionCheckerTest extends TestCase {
	/** @var PropertyMapper | MockObject */
	private $propertyMapper;

	/** @var IConfig | MockObject */
	private $config;

	/** @var ILogger | MockObject */
	private $logger;

	/** @var RetentionChecker */
	private $retentionChecker;

	protected function setUp(): void {
		parent::setUp();
		$this->propertyMapper = $this->createMock(PropertyMapper::class);
		$this->config = $this->createMock(IConfig::class);
		$this->logger = $this->createMock(ILogger::class);
		$this->retentionChecker = new RetentionChecker($this->propertyMapper, $this->config, $this->logger);
	}

	/**
	 * @dataProvider providesMtimes
	 */
	public function testRetentionByMtime($nodeMtime, $retentionTimestamp, $expected) {
		$this->config->method('getSystemValue')
			->with('workflow.tag-based-retention.use-upload-time', false)
			->willReturn(false);

		$node = $this->createMock(Node::class);
		$node->method('getId')
			->willReturn(666);

		$node->expects($this->once())->method('getMTime')
			->willReturn($nodeMtime);

		$isExpired = $this->retentionChecker->isRetentionOver($node, $retentionTimestamp);
		$this->assertEquals($expected, $isExpired);
	}

	public function providesMtimes() {
		return [
			[1, 100, true],
			[100, 1, false],
		];
	}

	/**
	 * @dataProvider providesUploadTimes
	 */
	public function testRetentionByUploadTime($nodeUploadDate, $retentionTimestamp, $expected) {
		$this->config->method('getSystemValue')
			->with('workflow.tag-based-retention.use-upload-time', false)
			->willReturn(true);

		$node = $this->createMock(Node::class);
		$node->method('getId')
			->willReturn(666);

		$prop = new DbProperty();
		$prop->setPropertyvalue($nodeUploadDate);

		$this->propertyMapper->expects($this->once())->method('findByIdAndPropertyName')
			->willReturn($prop);

		$isExpired = $this->retentionChecker->isRetentionOver($node, $retentionTimestamp);
		$this->assertEquals($expected, $isExpired);
	}

	public function providesUploadTimes() {
		return [
			['2019-09-24T00:00:00+00:00', 1569369600, true], // 1569369600 -> 2019-09-25T00:00:00+00:00
			['2019-09-26T00:00:00+00:00', 1569369600, false],
			[null, 1569369600, false],  // wrong date format
		];
	}
}
