<?php
/**
 * ownCloud
 *
 * @author Artur Neumann <artur@jankaritech.com>
 * @copyright Copyright (c) 2018 Artur Neumann artur@jankaritech.com
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License,
 * as published by the Free Software Foundation;
 * either version 3 of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>
 *
 */

use Behat\Behat\Context\Context;
use Behat\Behat\Hook\Scope\BeforeScenarioScope;
use Behat\Gherkin\Node\TableNode;
use PHPUnit\Framework\Assert;
use TestHelpers\HttpRequestHelper;

require_once 'bootstrap.php';

/**
 * Context with Workflow steps
 */
class WorkflowContext implements Context {
	/**
	 * @var FeatureContext
	 */
	private $featureContext;

	/**
	 * @var TagsContext
	 */
	private $tagsContext;

	/**
	 * @When the administrator creates a workflow named :workflowName setting tag :tagName with these rules using the API
	 *
	 * @param string $workflowName
	 * @param string $tagName
	 * @param TableNode $flows with column headings rule, value and operator
	 *
	 * @return void
	 */
	public function createWorkflowSetLastCreatedTag($workflowName, $tagName, TableNode $flows) {
		$this->featureContext->authContext->aNewBrowserSessionForTheAdministratorHasBeenStarted();
		$tagId = $this->tagsContext->findTagIdByName($tagName);
		foreach ($flows->getColumnsHash() as $flow) {
			$body = [
					'name' => $workflowName,
					'type' => 'workflow_autotagging',
					'conditions[0][rule]' => $flow['rule'],
					'conditions[0][value]' => $flow['value'],
					'conditions[0][operator]' => $flow['operator'],
					'actions[setTags][]' => $tagId
				];

			$headers = ['OCS-APIREQUEST' => 'true'];
			$headers['requesttoken'] = $this->featureContext->getRequestToken();
			$cookieJar = $this->featureContext->getCookieJar();
			
			$response = HttpRequestHelper::post(
				$this->featureContext->getBaseUrl() . "/index.php/apps/workflow/flow",
				$this->featureContext->getAdminUsername(),
				$this->featureContext->getAdminPassword(),
				$headers,
				$body,
				null,
				$cookieJar
			);
			Assert::assertSame(
				200,
				$response->getStatusCode(),
				"Failed to create workflow " . $response->getReasonPhrase()
			);
		}
	}
	
	/**
	 * @BeforeScenario
	 *
	 * @param BeforeScenarioScope $scope
	 *
	 * @return void
	 */
	public function setUpScenario(BeforeScenarioScope $scope) {
		// Get the environment
		$environment = $scope->getEnvironment();
		// Get all the contexts you need in this context
		$this->featureContext = $environment->getContext('FeatureContext');
		$this->tagsContext = $environment->getContext('TagsContext');
	}
}
